summaryrefslogtreecommitdiff
path: root/autogen.sh
diff options
context:
space:
mode:
authorvlefevre <vlefevre@280ebfd0-de03-0410-8827-d642c229c3f4>2017-11-27 10:31:33 +0000
committervlefevre <vlefevre@280ebfd0-de03-0410-8827-d642c229c3f4>2017-11-27 10:31:33 +0000
commit5c4fbc68adaf44a22a2c4d9923529e4558bf72f6 (patch)
tree1ea6bd40aa2b72dfde15ef661ed480dc40382fe9 /autogen.sh
parentf078962c47be438ff4cc97b76b28880c65a27888 (diff)
downloadmpfr-5c4fbc68adaf44a22a2c4d9923529e4558bf72f6.tar.gz
Updated autogen.sh so that doc/texinfo.tex isn't replaced.
git-svn-id: svn://scm.gforge.inria.fr/svn/mpfr/trunk@11841 280ebfd0-de03-0410-8827-d642c229c3f4
Diffstat (limited to 'autogen.sh')
-rwxr-xr-xautogen.sh21
1 files changed, 13 insertions, 8 deletions
diff --git a/autogen.sh b/autogen.sh
index fac425420..dc685164b 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -1,23 +1,28 @@
#!/bin/sh
# "autoreconf -f" will clobber our INSTALL file with a generic one if we
# don't move it out of the way.
# EXIT and signals that correspond to SIGHUP, SIGINT, SIGQUIT and SIGTERM.
signals="0 1 2 3 15"
+files="INSTALL doc/texinfo.tex"
+
cleanup()
{
trap '' $signals
- if [ -f INSTALL.$$.tmp ]; then
- echo "$0: restoring the INSTALL file" >&2
- mv -f INSTALL.$$.tmp INSTALL
- fi
+ for i in $files
+ do
+ if [ -f "$i.$$.tmp" ]; then
+ echo "$0: restoring the $i file" >&2
+ mv -f "$i.$$.tmp" "$i"
+ fi
+ done
}
-rm -f INSTALL.$$.tmp
+for i in $files; do rm -f -- "$i.$$.tmp"; done
trap cleanup $signals
-mv -f INSTALL INSTALL.$$.tmp
+for i in $files; do mv -f -- "$i" "$i.$$.tmp"; done
autoreconf -v -f -i --warnings=all,error
status=$?
@@ -1,23 +1,28 @@
#!/bin/sh
-# "autoreconf -f" will clobber our INSTALL file with a generic one if we
-# don't move it out of the way.
+# "autoreconf -f" will clobber some of our files with generic ones if we
+# don't move them out of the way (see $files below).
# EXIT and signals that correspond to SIGHUP, SIGINT, SIGQUIT and SIGTERM.
signals="0 1 2 3 15"